exceptiontools.TypographicWhitespaceError
=========================================

.. abjad-lineage:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError

.. autoclass:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__unicode__
   :noindex:
